Documentation
¶
Overview ¶
Package v1beta1 is the v1beta1 version of the API.
Package v1beta1 contains API Schema definitions for the LoadDistributionPolicy v1beta1 API group
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{ Group: "appgw.ingress.azure.io", Version: "v1beta1", } // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme adds all Resources to the Scheme AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Backend ¶
type Backend struct {
Service *v1.IngressServiceBackend `json:"service,omitempty"`
}
Backend defines a backend service
func (*Backend) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Backend.
func (*Backend) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoadDistributionPolicy ¶
type LoadDistributionPolicy struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// +optional
Spec LoadDistributionPolicySpec `json:"spec"`
}
LoadDistributionPolicy is the resource AGIC is watching on for any backend address change
func (*LoadDistributionPolicy) DeepCopy ¶
func (in *LoadDistributionPolicy) DeepCopy() *LoadDistributionPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadDistributionPolicy.
func (*LoadDistributionPolicy) DeepCopyInto ¶
func (in *LoadDistributionPolicy) DeepCopyInto(out *LoadDistributionPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoadDistributionPolicy) DeepCopyObject ¶
func (in *LoadDistributionPolicy) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LoadDistributionPolicyList ¶
type LoadDistributionPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []LoadDistributionPolicy `json:"items"`
}
LoadDistributionPolicyList is the list of LDP
func (*LoadDistributionPolicyList) DeepCopy ¶
func (in *LoadDistributionPolicyList) DeepCopy() *LoadDistributionPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadDistributionPolicyList.
func (*LoadDistributionPolicyList) DeepCopyInto ¶
func (in *LoadDistributionPolicyList) DeepCopyInto(out *LoadDistributionPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoadDistributionPolicyList) DeepCopyObject ¶
func (in *LoadDistributionPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LoadDistributionPolicySpec ¶
type LoadDistributionPolicySpec struct {
metav1.TypeMeta `json:",inline"`
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
//Targets include a list of backend targets
Targets []Target `json:"targets,omitempty"`
}
LoadDistributionPolicySpec defines a list of backend pool addresses
func (*LoadDistributionPolicySpec) DeepCopy ¶
func (in *LoadDistributionPolicySpec) DeepCopy() *LoadDistributionPolicySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoadDistributionPolicySpec.
func (*LoadDistributionPolicySpec) DeepCopyInto ¶
func (in *LoadDistributionPolicySpec) DeepCopyInto(out *LoadDistributionPolicySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Target ¶
type Target struct {
Role string `json:"role,omitempty"`
Weight int `json:"weight,omitempty"`
Backend Backend `json:"backend,omitempty"`
}
Target defines a backend service and its load distribution parameters
func (*Target) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Target.
func (*Target) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.