Documentation
¶
Overview ¶
Package v1alpha1 is the v1alpha1 version of the API.
Package v1alpha1 contains API Schema definitions for the GlobalServices v1alpha1 API group
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{ Group: "networking.aks.io", Version: "v1alpha1", } // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme adds all Resources to the Scheme AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type MultiClusterEndpoint ¶
type MultiClusterEndpoint struct {
Cluster string `json:"cluster,omitempty"`
Service string `json:"service,omitempty"`
IP string `json:"ip,omitempty"`
Endpoints []string `json:"endpoints,omitempty"`
}
MultiClusterEndpoint defines the endpoints for the multi cluster service.
func (*MultiClusterEndpoint) DeepCopy ¶
func (in *MultiClusterEndpoint) DeepCopy() *MultiClusterEndpoint
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterEndpoint.
func (*MultiClusterEndpoint) DeepCopyInto ¶
func (in *MultiClusterEndpoint) DeepCopyInto(out *MultiClusterEndpoint)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MultiClusterService ¶
type MultiClusterService struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MultiClusterServiceSpec `json:"spec,omitempty"`
Status MultiClusterServiceStatus `json:"status,omitempty"`
}
MultiClusterService is the Schema for the multi cluster services API
func (*MultiClusterService) DeepCopy ¶
func (in *MultiClusterService) DeepCopy() *MultiClusterService
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterService.
func (*MultiClusterService) DeepCopyInto ¶
func (in *MultiClusterService) DeepCopyInto(out *MultiClusterService)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MultiClusterService) DeepCopyObject ¶
func (in *MultiClusterService) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MultiClusterServiceList ¶
type MultiClusterServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []MultiClusterService `json:"items"`
}
MultiClusterServiceList contains a list of MultiClusterService
func (*MultiClusterServiceList) DeepCopy ¶
func (in *MultiClusterServiceList) DeepCopy() *MultiClusterServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterServiceList.
func (*MultiClusterServiceList) DeepCopyInto ¶
func (in *MultiClusterServiceList) DeepCopyInto(out *MultiClusterServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MultiClusterServiceList) DeepCopyObject ¶
func (in *MultiClusterServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MultiClusterServicePort ¶
type MultiClusterServicePort struct {
Name string `json:"name,omitempty"`
Protocol string `json:"protocol,omitempty"`
Port int `json:"port,omitempty"`
TargetPort int `json:"targetPort,omitempty"`
}
MultiClusterServicePort defines the spec for MultiClusterService port
func (*MultiClusterServicePort) DeepCopy ¶
func (in *MultiClusterServicePort) DeepCopy() *MultiClusterServicePort
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterServicePort.
func (*MultiClusterServicePort) DeepCopyInto ¶
func (in *MultiClusterServicePort) DeepCopyInto(out *MultiClusterServicePort)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MultiClusterServiceSpec ¶
type MultiClusterServiceSpec struct {
// LabelSelector for the multi cluster service. Services with the same name of MultiClusterService would be selected if the selector is not set.
Selector metav1.LabelSelector `json:"selector,omitempty"`
// Ports for the multi cluster service.
Ports []MultiClusterServicePort `json:"ports,omitempty"`
// ClusterSet for the multi cluster service.
ClusterSet string `json:"clusterSet,omitempty"`
}
MultiClusterServiceSpec defines the desired state of MultiClusterService
func (*MultiClusterServiceSpec) DeepCopy ¶
func (in *MultiClusterServiceSpec) DeepCopy() *MultiClusterServiceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterServiceSpec.
func (*MultiClusterServiceSpec) DeepCopyInto ¶
func (in *MultiClusterServiceSpec) DeepCopyInto(out *MultiClusterServiceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MultiClusterServiceStatus ¶
type MultiClusterServiceStatus struct {
// Endpoints represents a list of endpoint for the multi cluster service.
Endpoints []MultiClusterEndpoint `json:"endpoints,omitempty"`
VIP string `json:"vip,omitempty"`
State string `json:"state,omitempty"`
}
MultiClusterServiceStatus defines the observed state of MultiClusterService
func (*MultiClusterServiceStatus) DeepCopy ¶
func (in *MultiClusterServiceStatus) DeepCopy() *MultiClusterServiceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MultiClusterServiceStatus.
func (*MultiClusterServiceStatus) DeepCopyInto ¶
func (in *MultiClusterServiceStatus) DeepCopyInto(out *MultiClusterServiceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.