Documentation
¶
Overview ¶
This package has the automatically generated clientset.
Index ¶
- type Clientset
- func (c *Clientset) AzureapplicationgatewaybackendpoolsV1beta1() ...
- func (c *Clientset) AzureapplicationgatewayinstanceupdatestatusV1beta1() ...
- func (c *Clientset) AzureapplicationgatewayrewritesV1beta1() ...
- func (c *Clientset) AzureingressprohibitedtargetsV1() azureingressprohibitedtargetsv1.AzureingressprohibitedtargetsV1Interface
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) LoaddistributionpoliciesV1beta1() loaddistributionpoliciesv1beta1.LoaddistributionpoliciesV1beta1Interface
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
type Clientset struct {
*discovery.DiscoveryClient
// contains filtered or unexported fields
}
Clientset contains the clients for groups. Each group has exactly one version included in a Clientset.
func NewForConfig ¶
NewForConfig creates a new Clientset for the given config. If config's RateLimiter is not set and QPS and Burst are acceptable, NewForConfig will generate a rate-limiter in configShallowCopy.
func NewForConfigOrDie ¶
NewForConfigOrDie creates a new Clientset for the given config and panics if there is an error in the config.
func (*Clientset) AzureapplicationgatewaybackendpoolsV1beta1 ¶
func (c *Clientset) AzureapplicationgatewaybackendpoolsV1beta1() azureapplicationgatewaybackendpoolsv1beta1.AzureapplicationgatewaybackendpoolsV1beta1Interface
AzureapplicationgatewaybackendpoolsV1beta1 retrieves the AzureapplicationgatewaybackendpoolsV1beta1Client
func (*Clientset) AzureapplicationgatewayinstanceupdatestatusV1beta1 ¶
func (c *Clientset) AzureapplicationgatewayinstanceupdatestatusV1beta1() azureapplicationgatewayinstanceupdatestatusv1beta1.AzureapplicationgatewayinstanceupdatestatusV1beta1Interface
AzureapplicationgatewayinstanceupdatestatusV1beta1 retrieves the AzureapplicationgatewayinstanceupdatestatusV1beta1Client
func (*Clientset) AzureapplicationgatewayrewritesV1beta1 ¶
func (c *Clientset) AzureapplicationgatewayrewritesV1beta1() azureapplicationgatewayrewritesv1beta1.AzureapplicationgatewayrewritesV1beta1Interface
AzureapplicationgatewayrewritesV1beta1 retrieves the AzureapplicationgatewayrewritesV1beta1Client
func (*Clientset) AzureingressprohibitedtargetsV1 ¶
func (c *Clientset) AzureingressprohibitedtargetsV1() azureingressprohibitedtargetsv1.AzureingressprohibitedtargetsV1Interface
AzureingressprohibitedtargetsV1 retrieves the AzureingressprohibitedtargetsV1Client
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
Discovery retrieves the DiscoveryClient
func (*Clientset) LoaddistributionpoliciesV1beta1 ¶
func (c *Clientset) LoaddistributionpoliciesV1beta1() loaddistributionpoliciesv1beta1.LoaddistributionpoliciesV1beta1Interface
LoaddistributionpoliciesV1beta1 retrieves the LoaddistributionpoliciesV1beta1Client
type Interface ¶
type Interface interface {
Discovery() discovery.DiscoveryInterface
AzureapplicationgatewaybackendpoolsV1beta1() azureapplicationgatewaybackendpoolsv1beta1.AzureapplicationgatewaybackendpoolsV1beta1Interface
AzureapplicationgatewayinstanceupdatestatusV1beta1() azureapplicationgatewayinstanceupdatestatusv1beta1.AzureapplicationgatewayinstanceupdatestatusV1beta1Interface
AzureapplicationgatewayrewritesV1beta1() azureapplicationgatewayrewritesv1beta1.AzureapplicationgatewayrewritesV1beta1Interface
AzureingressprohibitedtargetsV1() azureingressprohibitedtargetsv1.AzureingressprohibitedtargetsV1Interface
LoaddistributionpoliciesV1beta1() loaddistributionpoliciesv1beta1.LoaddistributionpoliciesV1beta1Interface
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
typed
|
|
|
azureapplicationgatewaybackendpool/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
azureapplicationgatewaybackendpool/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
azureapplicationgatewayinstanceupdatestatus/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
azureapplicationgatewayinstanceupdatestatus/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
azureapplicationgatewayrewrite/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
azureapplicationgatewayrewrite/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
azureingressprohibitedtarget/v1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
azureingressprohibitedtarget/v1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
loaddistributionpolicy/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
loaddistributionpolicy/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |