Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AzureApplicationGatewayInstanceUpdateStatusExpansion ¶
type AzureApplicationGatewayInstanceUpdateStatusExpansion interface{}
type AzureApplicationGatewayInstanceUpdateStatusInterface ¶
type AzureApplicationGatewayInstanceUpdateStatusInterface interface {
Create(ctx context.Context, azureApplicationGatewayInstanceUpdateStatus *v1beta1.AzureApplicationGatewayInstanceUpdateStatus, opts v1.CreateOptions) (*v1beta1.AzureApplicationGatewayInstanceUpdateStatus, error)
Update(ctx context.Context, azureApplicationGatewayInstanceUpdateStatus *v1beta1.AzureApplicationGatewayInstanceUpdateStatus, opts v1.UpdateOptions) (*v1beta1.AzureApplicationGatewayInstanceUpdateStatus, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.AzureApplicationGatewayInstanceUpdateStatus, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.AzureApplicationGatewayInstanceUpdateStatusList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.AzureApplicationGatewayInstanceUpdateStatus, err error)
AzureApplicationGatewayInstanceUpdateStatusExpansion
}
AzureApplicationGatewayInstanceUpdateStatusInterface has methods to work with AzureApplicationGatewayInstanceUpdateStatus resources.
type AzureApplicationGatewayInstanceUpdateStatusesGetter ¶
type AzureApplicationGatewayInstanceUpdateStatusesGetter interface {
AzureApplicationGatewayInstanceUpdateStatuses() AzureApplicationGatewayInstanceUpdateStatusInterface
}
AzureApplicationGatewayInstanceUpdateStatusesGetter has a method to return a AzureApplicationGatewayInstanceUpdateStatusInterface. A group's client should implement this interface.
type AzureapplicationgatewayinstanceupdatestatusV1beta1Client ¶
type AzureapplicationgatewayinstanceupdatestatusV1beta1Client struct {
// contains filtered or unexported fields
}
AzureapplicationgatewayinstanceupdatestatusV1beta1Client is used to interact with features provided by the azureapplicationgatewayinstanceupdatestatus.appgw.ingress.azure.io group.
func New ¶
New creates a new AzureapplicationgatewayinstanceupdatestatusV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AzureapplicationgatewayinstanceupdatestatusV1beta1Client, error)
NewForConfig creates a new AzureapplicationgatewayinstanceupdatestatusV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AzureapplicationgatewayinstanceupdatestatusV1beta1Client
NewForConfigOrDie creates a new AzureapplicationgatewayinstanceupdatestatusV1beta1Client for the given config and panics if there is an error in the config.
func (*AzureapplicationgatewayinstanceupdatestatusV1beta1Client) AzureApplicationGatewayInstanceUpdateStatuses ¶
func (c *AzureapplicationgatewayinstanceupdatestatusV1beta1Client) AzureApplicationGatewayInstanceUpdateStatuses() AzureApplicationGatewayInstanceUpdateStatusInterface
func (*AzureapplicationgatewayinstanceupdatestatusV1beta1Client) RESTClient ¶
func (c *AzureapplicationgatewayinstanceupdatestatusV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AzureapplicationgatewayinstanceupdatestatusV1beta1Interface ¶
type AzureapplicationgatewayinstanceupdatestatusV1beta1Interface interface {
RESTClient() rest.Interface
AzureApplicationGatewayInstanceUpdateStatusesGetter
}