Documentation
¶
Index ¶
- func NewAzureIngressProhibitedTargetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredAzureIngressProhibitedTargetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type AzureIngressProhibitedTargetInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAzureIngressProhibitedTargetInformer ¶
func NewAzureIngressProhibitedTargetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewAzureIngressProhibitedTargetInformer constructs a new informer for AzureIngressProhibitedTarget type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredAzureIngressProhibitedTargetInformer ¶
func NewFilteredAzureIngressProhibitedTargetInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredAzureIngressProhibitedTargetInformer constructs a new informer for AzureIngressProhibitedTarget type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type AzureIngressProhibitedTargetInformer ¶
type AzureIngressProhibitedTargetInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1.AzureIngressProhibitedTargetLister
}
AzureIngressProhibitedTargetInformer provides access to a shared informer and lister for AzureIngressProhibitedTargets.
type Interface ¶
type Interface interface {
// AzureIngressProhibitedTargets returns a AzureIngressProhibitedTargetInformer.
AzureIngressProhibitedTargets() AzureIngressProhibitedTargetInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.