Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AzureApplicationGatewayBackendPoolLister ¶
type AzureApplicationGatewayBackendPoolLister interface {
// List lists all AzureApplicationGatewayBackendPools in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.AzureApplicationGatewayBackendPool, err error)
// Get retrieves the AzureApplicationGatewayBackendPool from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.AzureApplicationGatewayBackendPool, error)
AzureApplicationGatewayBackendPoolListerExpansion
}
AzureApplicationGatewayBackendPoolLister helps list AzureApplicationGatewayBackendPools. All objects returned here must be treated as read-only.
func NewAzureApplicationGatewayBackendPoolLister ¶
func NewAzureApplicationGatewayBackendPoolLister(indexer cache.Indexer) AzureApplicationGatewayBackendPoolLister
NewAzureApplicationGatewayBackendPoolLister returns a new AzureApplicationGatewayBackendPoolLister.
type AzureApplicationGatewayBackendPoolListerExpansion ¶
type AzureApplicationGatewayBackendPoolListerExpansion interface{}
AzureApplicationGatewayBackendPoolListerExpansion allows custom methods to be added to AzureApplicationGatewayBackendPoolLister.
Click to show internal directories.
Click to hide internal directories.