Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AzureApplicationGatewayInstanceUpdateStatusLister ¶
type AzureApplicationGatewayInstanceUpdateStatusLister interface {
// List lists all AzureApplicationGatewayInstanceUpdateStatuses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.AzureApplicationGatewayInstanceUpdateStatus, err error)
// Get retrieves the AzureApplicationGatewayInstanceUpdateStatus from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.AzureApplicationGatewayInstanceUpdateStatus, error)
AzureApplicationGatewayInstanceUpdateStatusListerExpansion
}
AzureApplicationGatewayInstanceUpdateStatusLister helps list AzureApplicationGatewayInstanceUpdateStatuses. All objects returned here must be treated as read-only.
func NewAzureApplicationGatewayInstanceUpdateStatusLister ¶
func NewAzureApplicationGatewayInstanceUpdateStatusLister(indexer cache.Indexer) AzureApplicationGatewayInstanceUpdateStatusLister
NewAzureApplicationGatewayInstanceUpdateStatusLister returns a new AzureApplicationGatewayInstanceUpdateStatusLister.
type AzureApplicationGatewayInstanceUpdateStatusListerExpansion ¶
type AzureApplicationGatewayInstanceUpdateStatusListerExpansion interface{}
AzureApplicationGatewayInstanceUpdateStatusListerExpansion allows custom methods to be added to AzureApplicationGatewayInstanceUpdateStatusLister.
Click to show internal directories.
Click to hide internal directories.