Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AzureIngressProhibitedTargetLister ¶
type AzureIngressProhibitedTargetLister interface {
// List lists all AzureIngressProhibitedTargets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.AzureIngressProhibitedTarget, err error)
// AzureIngressProhibitedTargets returns an object that can list and get AzureIngressProhibitedTargets.
AzureIngressProhibitedTargets(namespace string) AzureIngressProhibitedTargetNamespaceLister
AzureIngressProhibitedTargetListerExpansion
}
AzureIngressProhibitedTargetLister helps list AzureIngressProhibitedTargets. All objects returned here must be treated as read-only.
func NewAzureIngressProhibitedTargetLister ¶
func NewAzureIngressProhibitedTargetLister(indexer cache.Indexer) AzureIngressProhibitedTargetLister
NewAzureIngressProhibitedTargetLister returns a new AzureIngressProhibitedTargetLister.
type AzureIngressProhibitedTargetListerExpansion ¶
type AzureIngressProhibitedTargetListerExpansion interface{}
AzureIngressProhibitedTargetListerExpansion allows custom methods to be added to AzureIngressProhibitedTargetLister.
type AzureIngressProhibitedTargetNamespaceLister ¶
type AzureIngressProhibitedTargetNamespaceLister interface {
// List lists all AzureIngressProhibitedTargets in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.AzureIngressProhibitedTarget, err error)
// Get retrieves the AzureIngressProhibitedTarget from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.AzureIngressProhibitedTarget, error)
AzureIngressProhibitedTargetNamespaceListerExpansion
}
AzureIngressProhibitedTargetNamespaceLister helps list and get AzureIngressProhibitedTargets. All objects returned here must be treated as read-only.
type AzureIngressProhibitedTargetNamespaceListerExpansion ¶
type AzureIngressProhibitedTargetNamespaceListerExpansion interface{}
AzureIngressProhibitedTargetNamespaceListerExpansion allows custom methods to be added to AzureIngressProhibitedTargetNamespaceLister.
Click to show internal directories.
Click to hide internal directories.