Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MultiClusterIngressLister ¶
type MultiClusterIngressLister interface {
// List lists all MultiClusterIngresses in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MultiClusterIngress, err error)
// MultiClusterIngresses returns an object that can list and get MultiClusterIngresses.
MultiClusterIngresses(namespace string) MultiClusterIngressNamespaceLister
MultiClusterIngressListerExpansion
}
MultiClusterIngressLister helps list MultiClusterIngresses. All objects returned here must be treated as read-only.
func NewMultiClusterIngressLister ¶
func NewMultiClusterIngressLister(indexer cache.Indexer) MultiClusterIngressLister
NewMultiClusterIngressLister returns a new MultiClusterIngressLister.
type MultiClusterIngressListerExpansion ¶
type MultiClusterIngressListerExpansion interface{}
MultiClusterIngressListerExpansion allows custom methods to be added to MultiClusterIngressLister.
type MultiClusterIngressNamespaceLister ¶
type MultiClusterIngressNamespaceLister interface {
// List lists all MultiClusterIngresses in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MultiClusterIngress, err error)
// Get retrieves the MultiClusterIngress from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.MultiClusterIngress, error)
MultiClusterIngressNamespaceListerExpansion
}
MultiClusterIngressNamespaceLister helps list and get MultiClusterIngresses. All objects returned here must be treated as read-only.
type MultiClusterIngressNamespaceListerExpansion ¶
type MultiClusterIngressNamespaceListerExpansion interface{}
MultiClusterIngressNamespaceListerExpansion allows custom methods to be added to MultiClusterIngressNamespaceLister.
Click to show internal directories.
Click to hide internal directories.