Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MultiClusterServiceLister ¶
type MultiClusterServiceLister interface {
// List lists all MultiClusterServices in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MultiClusterService, err error)
// MultiClusterServices returns an object that can list and get MultiClusterServices.
MultiClusterServices(namespace string) MultiClusterServiceNamespaceLister
MultiClusterServiceListerExpansion
}
MultiClusterServiceLister helps list MultiClusterServices. All objects returned here must be treated as read-only.
func NewMultiClusterServiceLister ¶
func NewMultiClusterServiceLister(indexer cache.Indexer) MultiClusterServiceLister
NewMultiClusterServiceLister returns a new MultiClusterServiceLister.
type MultiClusterServiceListerExpansion ¶
type MultiClusterServiceListerExpansion interface{}
MultiClusterServiceListerExpansion allows custom methods to be added to MultiClusterServiceLister.
type MultiClusterServiceNamespaceLister ¶
type MultiClusterServiceNamespaceLister interface {
// List lists all MultiClusterServices in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.MultiClusterService, err error)
// Get retrieves the MultiClusterService from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.MultiClusterService, error)
MultiClusterServiceNamespaceListerExpansion
}
MultiClusterServiceNamespaceLister helps list and get MultiClusterServices. All objects returned here must be treated as read-only.
type MultiClusterServiceNamespaceListerExpansion ¶
type MultiClusterServiceNamespaceListerExpansion interface{}
MultiClusterServiceNamespaceListerExpansion allows custom methods to be added to MultiClusterServiceNamespaceLister.
Click to show internal directories.
Click to hide internal directories.