Documentation
¶
Index ¶
- type DestinationRuleLister
- type DestinationRuleListerExpansion
- type DestinationRuleNamespaceLister
- type DestinationRuleNamespaceListerExpansion
- type GatewayLister
- type GatewayListerExpansion
- type GatewayNamespaceLister
- type GatewayNamespaceListerExpansion
- type VirtualServiceLister
- type VirtualServiceListerExpansion
- type VirtualServiceNamespaceLister
- type VirtualServiceNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DestinationRuleLister ¶
type DestinationRuleLister interface {
// List lists all DestinationRules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.DestinationRule, err error)
// DestinationRules returns an object that can list and get DestinationRules.
DestinationRules(namespace string) DestinationRuleNamespaceLister
DestinationRuleListerExpansion
}
DestinationRuleLister helps list DestinationRules. All objects returned here must be treated as read-only.
func NewDestinationRuleLister ¶
func NewDestinationRuleLister(indexer cache.Indexer) DestinationRuleLister
NewDestinationRuleLister returns a new DestinationRuleLister.
type DestinationRuleListerExpansion ¶
type DestinationRuleListerExpansion interface{}
DestinationRuleListerExpansion allows custom methods to be added to DestinationRuleLister.
type DestinationRuleNamespaceLister ¶
type DestinationRuleNamespaceLister interface {
// List lists all DestinationRules in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.DestinationRule, err error)
// Get retrieves the DestinationRule from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha3.DestinationRule, error)
DestinationRuleNamespaceListerExpansion
}
DestinationRuleNamespaceLister helps list and get DestinationRules. All objects returned here must be treated as read-only.
type DestinationRuleNamespaceListerExpansion ¶
type DestinationRuleNamespaceListerExpansion interface{}
DestinationRuleNamespaceListerExpansion allows custom methods to be added to DestinationRuleNamespaceLister.
type GatewayLister ¶
type GatewayLister interface {
// List lists all Gateways in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.Gateway, err error)
// Gateways returns an object that can list and get Gateways.
Gateways(namespace string) GatewayNamespaceLister
GatewayListerExpansion
}
GatewayLister helps list Gateways. All objects returned here must be treated as read-only.
func NewGatewayLister ¶
func NewGatewayLister(indexer cache.Indexer) GatewayLister
NewGatewayLister returns a new GatewayLister.
type GatewayListerExpansion ¶
type GatewayListerExpansion interface{}
GatewayListerExpansion allows custom methods to be added to GatewayLister.
type GatewayNamespaceLister ¶
type GatewayNamespaceLister interface {
// List lists all Gateways in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.Gateway, err error)
// Get retrieves the Gateway from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha3.Gateway, error)
GatewayNamespaceListerExpansion
}
GatewayNamespaceLister helps list and get Gateways. All objects returned here must be treated as read-only.
type GatewayNamespaceListerExpansion ¶
type GatewayNamespaceListerExpansion interface{}
GatewayNamespaceListerExpansion allows custom methods to be added to GatewayNamespaceLister.
type VirtualServiceLister ¶
type VirtualServiceLister interface {
// List lists all VirtualServices in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.VirtualService, err error)
// VirtualServices returns an object that can list and get VirtualServices.
VirtualServices(namespace string) VirtualServiceNamespaceLister
VirtualServiceListerExpansion
}
VirtualServiceLister helps list VirtualServices. All objects returned here must be treated as read-only.
func NewVirtualServiceLister ¶
func NewVirtualServiceLister(indexer cache.Indexer) VirtualServiceLister
NewVirtualServiceLister returns a new VirtualServiceLister.
type VirtualServiceListerExpansion ¶
type VirtualServiceListerExpansion interface{}
VirtualServiceListerExpansion allows custom methods to be added to VirtualServiceLister.
type VirtualServiceNamespaceLister ¶
type VirtualServiceNamespaceLister interface {
// List lists all VirtualServices in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha3.VirtualService, err error)
// Get retrieves the VirtualService from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha3.VirtualService, error)
VirtualServiceNamespaceListerExpansion
}
VirtualServiceNamespaceLister helps list and get VirtualServices. All objects returned here must be treated as read-only.
type VirtualServiceNamespaceListerExpansion ¶
type VirtualServiceNamespaceListerExpansion interface{}
VirtualServiceNamespaceListerExpansion allows custom methods to be added to VirtualServiceNamespaceLister.