mocks

package
v0.0.0-...-36a8cee Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 4, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Clock

type Clock struct{}

Clock is a custom implementation of Time.

func (Clock) After

func (Clock) After(d time.Duration) <-chan time.Time

After is what it was before.

func (Clock) Now

func (Clock) Now() time.Time

Now is a static never changing Time.

type MockLogger

type MockLogger struct {
	// LogLines is the string list, where we accumulate log lines.
	LogLines []string
}

MockLogger is a struct, which allows mocking of the logging facility.

func (*MockLogger) Info

func (m *MockLogger) Info(args ...interface{})

Info emits a log line.

Jump to