Documentation
¶
Index ¶
Constants ¶
const ( ResourceManagedByLabel = "app.kubernetes.io/managed-by" ResourceManagedByAddonValue = "ingress-appgw-addon" ResourceManagedByHelmValue = "ingress-appgw-helm" )
const ( // PodNetworkTypeLabel is the name of the label on NNCs to tell what mode the network is in. PodNetworkTypeLabel = "kubernetes.azure.com/podnetwork-type" // OverlayExtensionConfigName is the name of the overlay extension config resource OverlayExtensionConfigName = "agic-overlay-extension-config" // OverlayConfigReconcileTimeout for checking overlay extension config status OverlayConfigReconcileTimeout = 30 * time.Second // OverlayConfigReconcilePollInterval for checking overlay extension config status OverlayConfigReconcilePollInterval = 2 * time.Second )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Reconciler ¶
type Reconciler struct {
// contains filtered or unexported fields
}
Reconciler reconciles the resources required to configure CNI on the AKS cluster.
func NewReconciler ¶
func NewReconciler(armClient azure.AzClient, client client.Client, recorder record.EventRecorder, cpConfig *azure.CloudProviderConfig, appGw n.ApplicationGateway, agicPod *v1.Pod, namespace string, addonMode bool) *Reconciler
Click to show internal directories.
Click to hide internal directories.