Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clock ¶
type Clock struct{}
Clock is a custom implementation of Time.
type MockLogger ¶
type MockLogger struct {
// LogLines is the string list, where we accumulate log lines.
LogLines []string
}
MockLogger is a struct, which allows mocking of the logging facility.
Click to show internal directories.
Click to hide internal directories.